pub struct OpenSearchComponent { /* private fields */ }Implementations
Sourceimpl OpenSearchComponent
impl OpenSearchComponent
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new OpenSearchComponent without global config defaults.
Endpoint configs will fall back to hardcoded defaults via merge_with_global().
Sourcepub fn with_config(config: OpenSearchConfig) -> Self
pub fn with_config(config: OpenSearchConfig) -> Self
Create an OpenSearchComponent with global config defaults. These will be applied to endpoint configs when specific values aren’t provided.
Sourcepub fn with_optional_config(config: Option<OpenSearchConfig>) -> Self
pub fn with_optional_config(config: Option<OpenSearchConfig>) -> Self
Create an OpenSearchComponent with optional global config defaults.
If None, behaves like new() (uses hardcoded defaults only).